<?php
    /**
     * @var View         $this
     * @var string       $content
     * @var SeoComponent $seo
     * @var User         $user
     */
    use artbox\core\components\SeoComponent;
    use artbox\core\helpers\ImageHelper;
    use artbox\core\models\Feedback;
    use artbox\core\models\Page;
    use artbox\core\models\User;
    use common\models\Settings;
    use frontend\assets\AppAsset;
    use noam148\imagemanager\models\ImageManager;
    use yii\bootstrap\ActiveForm;
    use yii\bootstrap\Nav;
    use yii\bootstrap\Html;
    use yii\helpers\Json;
    use yii\helpers\Url;
    use yii\web\View;
    use frontend\widgets\SeoBreadcrumbs;
    use \artbox\core\models\Language;
    
    AppAsset::register($this);
    $user = \Yii::$app->user->identity;
    $seo = Yii::$app->get('seo');
    $feedback = new Feedback();
    $settings = Settings::getInstance();
    $controller = Yii::$app->controller;
    $default_controller = Yii::$app->defaultRoute;
    $isHome = ( ( $controller->id === $default_controller ) && ( $controller->action->id === $controller->defaultAction ) ) ? true : false;
    /**
     * @var Page[] $pages
     */
    $pages = Page::find()
                 ->where([ 'in_menu' => true ])
                 ->with('lang.alias')
                 ->all();
    $logo = null;
    if ($settings->logo) {
        $logo_img = ImageManager::findOne($settings->logo);
        if ($logo_img) {
            $logo = $logo_img->getImagePathPrivate() ?? $logo;
        }
    }
    
    $this->registerMetaTag(
        [
            'name'    => 'description',
            'content' => !empty($seo->desc)?$seo->desc:(isset($this->params['desc'])?$this->params['desc']:""),
        ]
    );
?>

<?php $this->beginPage() ?>
  
  <!DOCTYPE html>
  <html lang="<?= \Yii::$app->language ?>">
    <head>
      <meta charset="<?= \Yii::$app->charset ?>">
      <meta name="viewport" content="width=device-width, initial-scale=1">
        <?= Html::csrfMetaTags() ?>
      <title><?= !empty(Html::encode($seo->title))?Html::encode($seo->title):(isset($this->params['title'])?$this->params['title']:'')?></title>
        <?php $this->head() ?>
        <style>
            html,body{padding:0!important;margin:0!important;}
            #heading-breadcrumbs{background: #986dbd;color:#fff;}
            #heading-breadcrumbs h1{color:#fff;}
            #heading-breadcrumbs ul li a span{color: #c1a7d7;}
            #heading-breadcrumbs .breadcrumb>.active{color: #d6c5e5;}
            #heading-breadcrumbs .breadcrumb>li+li:before{color: #d6c5e5;}
            #back-to-top {background: #8f67b1;}
            #back-to-top:hover {background: #653d87;}
            .owl-item .item {position: relative;height: 0;padding-bottom: 59%;max-height: 500px;overflow: hidden;}
            .owl-item .item .itemimage {position: absolute;width: 100%;height: 100%;background-position: center center;background-size: cover;}
            .owl-carousel .owl-wrapper-outer{background-color: #e8e7e9;}
            @media(max-width:767px){
                .dropdown-menu li a{max-width: 100%;display: block;white-space: normal;}
                .btn-template-transparent-primary{margin: 10px 0px;}
            }
            .navbar-affixed-top.affix{z-index:10000;}
        </style>
    </head>
    <body>
        <?php $this->beginBody() ?>
        <!-- Global Site Tag (gtag.js) - Google Analytics -->
        <script async src="https://www.googletagmanager.com/gtag/js?id=UA-106355704-1"></script>
        <script>
            window.dataLayer = window.dataLayer || [];
            function gtag(){dataLayer.push(arguments);}
            gtag('js', new Date());

            gtag('config', 'UA-106355704-1');
        </script>
      <div id="all">
        <header>
          <!-- *** TOP ***
_________________________________________________________ -->
          <div id="top">
            <div class="container">
              <div class="row">
                <div class="col-xs-5 contact">
                  <p class="hidden-sm hidden-xs">
                      <?php
                          if (!empty($settings->phone)) {
                              $phone = str_replace(' ', '', $settings->phone);
                              echo \Yii::t('app', 'Свяжитесь с нами ');
                              echo Html::a($settings->phone, "tel:{$phone}");
                              if (!empty($settings->email)) {
                                  echo \Yii::t('app', ' или ');
                                  echo Html::a($settings->email, "mailto:$settings->email");
                              }
                          }
                      ?>
                  </p>
                  <p class="hidden-md hidden-lg">
                      <?php
                      if (!empty($settings->phone)) {
                          $phone = str_replace(' ', '', $settings->phone);
                          echo '<a href="tel:'.$phone.'" data-animate-hover="pulse"><i class="fa fa-phone"></i></a>';
                          if (!empty($settings->email)) {
                              echo '<a href="mailto:'.$settings->email.'" data-animate-hover="pulse"><i class="fa fa-envelope"></i></a>';
                          }
                      }
                      ?>
                  </p>
                </div>
                <div class="col-xs-7">
                  <div class="social">
                      <?php
                          if (!empty($settings->facebook)) {
                              echo Html::a(
                                  Html::icon(
                                      'facebook',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->facebook,
                                  [
                                      'class' => 'external facebook',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->vk)) {
                              echo Html::a(
                                  Html::icon(
                                      'vk',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->vk,
                                  [
                                      'class' => 'external vk',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->google)) {
                              echo Html::a(
                                  Html::icon(
                                      'google-plus',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->google,
                                  [
                                      'class' => 'external gplus',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->twitter)) {
                              echo Html::a(
                                  Html::icon(
                                      'twitter',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->twitter,
                                  [
                                      'class' => 'external twitter',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->ok)) {
                              echo Html::a(
                                  Html::icon(
                                      'odnoklassniki',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->ok,
                                  [
                                      'class' => 'external odnoklassniki',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->email)) {
                              echo Html::a(
                                  Html::icon(
                                      'envelope',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  "mailto:$settings->email",
                                  [
                                      'class' => 'email',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                  </div>
                </div>
              </div>
            </div>
          </div>
          <!-- *** TOP END *** -->
          
          <!-- *** NAVBAR ***
  _________________________________________________________ -->
          <div class="navbar-affixed-top" data-spy="affix" data-offset-top="200">
            
            <div class="navbar navbar-default yamm" role="navigation" id="navbar">
              
              <div class="container">
                <div class="navbar-header">
                  
                  <a class="navbar-brand home" href="<?php echo Url::home(); ?>">
                      <?php
                          echo ImageHelper::set($logo)
                                          ->setHeight(42)
                                          ->quality(40)
                                          ->renderImage(
                                              [
                                                  'alt' => $settings->name,
                                              ]
                                          )
                      ?>
                  </a>
                  <div class="navbar-buttons">
                    <button type="button" class="navbar-toggle btn-template-main" data-toggle="collapse" data-target="#navigation">
                      <span class="sr-only">Toggle navigation</span>
                      <i class="fa fa-align-justify"></i>
                    </button>
                  </div>
                </div>
                
                <div class="navbar-collapse collapse" id="navigation">
                    <?php
                        $pagesLinks = [];
                        foreach ($pages as $page) {
                            $route = [
                                'page/view',
                                'id' => $page->id,
                            ];
                            if (!empty($page->lang->alias) && !empty($page->lang->alias->route)) {
                                $route = Json::decode($page->lang->alias->route);
                            }
                            $pagesLinks[] = [
                                'label' => $page->lang->title,
                                'url'   => $route,
                            ];
                        }
                        echo Nav::widget(
                            [
                                'items'   => [
                                    [
                                        'label' => \Yii::t('app', 'Главная'),
                                        'url'   => [ 'site/index' ],
                                    ],
                                    [
                                        'label'   => \Yii::t('app', 'Решения'),
                                        'items'   => $pagesLinks,
                                        'visible' => count($pagesLinks),
                                    ],
                                    [
                                        'label' => \Yii::t('app', 'Контакты'),
                                        'url'   => [ '/contact' ],
                                    ],
                                    [
                                        'label' => \Yii::t('app', 'О нас'),
                                        'url'   => [ '/about' ],
                                    ],
                                ],
                                'options' => [
                                    'class' => 'nav navbar-nav navbar-right',
                                ],
                            ]
                        );
                    ?>
                </div>
                
                
                <div class="collapse clearfix" id="search">
                  
                  <form class="navbar-form" role="search">
                    <div class="input-group">
                      <input type="text" class="form-control" placeholder="Найти">
                      <span class="input-group-btn">

                    <button type="submit" class="btn btn-template-main"><i class="fa fa-search"></i></button>

                </span>
                    </div>
                  </form>
                
                </div>
                <!--/.nav-collapse -->
              
              </div>
            
            
            </div>
            <!-- /#navbar -->
          
          </div>
          
          <!-- *** NAVBAR END *** -->
        
        </header>
        
        <!-- *** FeedBack MODAL ***
_________________________________________________________ -->
        
        <div class="modal fade" id="feedback-modal" tabindex="-1" role="dialog" aria-labelledby="Login" aria-hidden="true">
          <div class="modal-dialog">
            
            <div class="modal-content">
              <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
                <h3 class="modal-title" id="Login">Обратная связь</h3>
              </div>
              <div class="modal-body">
                  
                  <?php $form = ActiveForm::begin(
                      [
                          'id'     => 'feedback-form',
                          'method' => 'POST',
                          'action' => '/site/feedback',
                      ]
                  ); ?>
                  
                  <?= \yii\helpers\Html::hiddenInput(
                      'Feedback[subject]',
                      'default Val',
                      [
                          'class' => 't_subject'
                      ]
                  )?>
                  
                  <?= $form->field($feedback, 'name')
                           ->textInput(); ?>
                  
                  <?= $form->field($feedback, 'email')
                           ->textInput(); ?>
                  
                  <?= $form->field($feedback, 'phone')
                           ->textInput(); ?>
                  
                  <?= $form->field($feedback, 'message')
                           ->textarea(
                               [
                                   'rows' => 4,
                               ]
                           ); ?>
                
                <p class="text-center">
                    <?= Html::submitButton(
                        'Отправить',
                        [
                            'class' => 'send-form btn btn-lg btn-template-primary btn-first-send',
                            'onclick' => "gtag('event', 'button', {'event_category': button-order,'event_action': click});",
                        ]
                    ) ?>
                </p>
                <p class="text-center">
                    <?= Html::submitButton(
                        'Отправить',
                        [
                            'class' => 'send-form btn btn-lg btn-template-primary btn-second-send',
                            'onclick' => "gtag('event', 'button', {'event_category': button-write,'event_action': click});",
                        ]
                    ) ?>
                </p>
                  
                  <?php ActiveForm::end(); ?>
              
              </div>
            </div>
          </div>
        </div>
        
        <!-- *** FeedBack MODAL END *** -->
        
        <!-- *** FeedBack MODAL ***
_________________________________________________________ -->
        
        <div class="modal fade" id="success-modal" tabindex="-1" role="dialog" aria-labelledby="Success" aria-hidden="true">
          <div class="modal-dialog">
            
            <div class="modal-content">
              <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
                <h3 class="modal-title" id="Success">Success</h3>
              </div>
              <div class="modal-body">
                
                <p>Спасибо, ваша заявка принята. Мы свяжемся с вами в ближайшее время</p>
                <p class="text-center">
                  <button type="button" class="btn btn-template-primary" data-dismiss="modal"><?=\Yii::t("app", "Close")?></button>
                </p>
              </div>
            </div>
          </div>
        </div>
        
        <!-- *** FeedBack MODAL END *** -->
        
        <!-- *** Breadcrumbs *** -->
          <?php
              if (!$isHome) {
                  ?>
                <div id="heading-breadcrumbs">
                  <div class="container">
                    <div class="row">
                      <div class="col-md-7">
                        <h1 class="main"><?= !empty($seo->h1)?$seo->h1:(!empty($this->params['title'])?$this->params['title']:'') ?></h1>
                      </div>
                      <div class="col-md-5">
                          <?php
                              if( isset($this->params['breadcrumbs']) && is_array($this->params['breadcrumbs']) ){
                                  echo SeoBreadcrumbs::widget(
                                      [
                                          'links' => $this->params[ 'breadcrumbs' ],
                                          'encodeLabels' => false,
                                          'homeLink' => [
                                              'label' => "<span itemprop='name'>". \Yii::t('app', "Home") ."</span>",
                                              'url' => "/ru",
                                              'itemprop' => 'item',
                                          ]
                                      ]
                                  );
                              }
                          ?>
                      
                      </div>
                    </div>
                  </div>
                </div>
                  <?php
              }
          ?>
        <!-- *** Breadcrumbs END *** -->
          
          <?= $content ?>
        
        <!-- *** FOOTER ***
_________________________________________________________ -->
        
        <footer id="footer">
          <div class="container">
            <div class="col-md-6 col-sm-12">
                <?php
                    if (!empty($settings->about)) {
                        ?>
                      <span class="title"><?php echo \Yii::t('app', 'О нас'); ?></span>
                      <p><?php echo $settings->about; ?></p>
                        <?php
                    }
                ?>
              <a href="#" class="btn btn-template-transparent-primary do-order-but but-writeus" data-toggle="modal" data-target="#feedback-modal" data-modalname="Обратная связь">Написать нам!</a>
            </div>
            
            <div class="col-md-4 col-sm-12 col-md-offset-2">
              
              <span class="title"><?php echo \Yii::t('app', 'Контакты'); ?></span>
              
              <p>
                  <?php
                      if (!empty($settings->office)) {
                          echo \Yii::t(
                                  'app',
                                  'Офис {office}',
                                  [
                                      'office' => $settings->office,
                                  ]
                              ) . Html::tag('br');
                      }
                      if (!empty($settings->street)) {
                          echo $settings->street;
                          if (!empty($settings->house)) {
                              echo " " . $settings->house;
                          }
                          echo Html::tag('br');
                      }
                      if (!empty($settings->city)) {
                          echo $settings->city;
                          echo Html::tag('br');
                      }
                      if (!empty($settings->country)) {
                          echo Html::tag('strong', $settings->country);
                      }
                  ?>
              </p>
                
                <?= Html::a(
                    'На страницу контактов',
                    [ '/contact' ],
                    [
                        'class' => 'btn btn-small btn-template-transparent-primary',
                    ]
                ) ?>
              
              <hr class="hidden-md hidden-lg hidden-sm">
            
            </div>
            
            <div class="col-md-12">
              <p class="pull-left">&copy; <?= date('Y') ?>. <?= $settings->name; ?></p>
            </div>
          </div>
          <!-- /.container -->
        </footer>
        <!-- /#footer -->
        
        <!-- *** FOOTER END *** -->
        
        <span id="back-to-top" title="Back to top"><i class="fa fa-arrow-up"></i></span>
      
      </div>
      <!-- /#all -->
        <?php $this->endBody() ?>
    </body>
  </html>
<?php $this->endPage() ?>